@@ -51,15 +51,15 @@ class B2GPopulate(object):
 
     PERSISTENT_STORAGE_PATH = '/data/local/storage/persistent'
 
+    handler = mozlog.StreamHandler()
+    handler.setFormatter(mozlog.MozFormatter(include_timestamp=True))
+    logger = mozlog.getLogger('B2GPopulate', handler)
+
     def __init__(self, marionette, log_level='INFO'):
         self.marionette = marionette
         self.data_layer = GaiaData(self.marionette)
         self.device = GaiaDevice(self.marionette)
 
-        # Set up logging
-        handler = mozlog.StreamHandler()
-        handler.setFormatter(B2GPopulateFormatter())
-        self.logger = mozlog.getLogger(self.__class__.__name__, handler)
         self.logger.setLevel(getattr(mozlog, log_level.upper()))
 
         if self.device.is_android_build:
@@ -136,11 +136,14 @@ class B2GPopulate(object):
                     self.start_b2g()
                 break
 
-    def populate_contacts(self, count, restart=True):
+    def populate_contacts(self, count, restart=True, include_pictures=True):
         # only allow preset db values for contacts
         db_counts = DB_PRESET_COUNTS['contact']
         if not count in db_counts:
             raise InvalidCountError('contact')
+        self.device.manager.removeDir('/'.join([
+            self.PERSISTENT_STORAGE_PATH, 'chrome',
+            self.idb_dir, '*csotncta*']))
         self.logger.info('Populating %d contacts' % count)
         db_counts.sort(reverse=True)
         for marker in db_counts:
@@ -161,7 +164,7 @@ class B2GPopulate(object):
                 self.device.push_file(db, destination=destination)
                 self.logger.debug('Removing %s' % db)
                 os.remove(db)
-                if marker > 0:
+                if marker > 0 and include_pictures:
                     self.logger.debug('Adding contact pictures')
                     pictures_zip_name = pkg_resources.resource_filename(
                         __name__, os.path.sep.join(
@@ -341,19 +344,6 @@ class B2GPopulate(object):
         self.data_layer = GaiaData(self.marionette)
 
 
-class B2GPopulateFormatter(mozlog.MozFormatter):
-
-    def format(self, record):
-        record.message = record.getMessage()
-        import datetime
-        record.timestamp = datetime.datetime.fromtimestamp(
-            int(record.created)).strftime('%Y-%m-%d %H:%M:%S')
-        sep = ' | '
-        fmt = sep.join(['%(timestamp)s', '%(name)s', '%(levelname)s',
-                        '%(message)s'])
-        return fmt % record.__dict__
-
-
 def cli():
     parser = OptionParser(usage='%prog [options]')
     parser.add_option(
